@@ -16,9 +16,10 @@ from typing import (
     TypedDict,
     TypeVar,
     cast,
-    dataclass_transform,
 )
 
+from typing_extensions import dataclass_transform
+
 _T = TypeVar('_T')
 
 
